CreateAccessPointRequest class

Constructors

CreateAccessPointRequest({required String accountId, required String bucket, required String name, PublicAccessBlockConfiguration? publicAccessBlockConfiguration, VpcConfiguration? vpcConfiguration})

Properties

accountId → String
The AWS account ID for the owner of the bucket for which you want to create an access point.
final
bucket → String
The name of the bucket that you want to associate this access point with.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
The name you want to assign to this access point.
final
publicAccessBlockConfiguration → PublicAccessBlockConfiguration?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vpcConfiguration → VpcConfiguration?
If you include this field, Amazon S3 restricts access to this access point to requests from the specified virtual private cloud (VPC).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toXml(String elemName, {List<XmlAttribute>? attributes}) → XmlElement

Operators

operator ==(Object other) → bool
The equality operator.
inherited