CreateBucketResult class

Constructors

CreateBucketResult({String? bucketArn, String? location})

Properties

bucketArn → String?
The Amazon Resource Name (ARN) of the bucket.
final
hashCode → int
The hash code for this object.
no setterinherited
location → String?
The location of the bucket.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited