CreateJobResult class

Constructors

CreateJobResult({String? jobId})
CreateJobResult.fromXml(XmlElement elem)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
jobId → String?
The ID for this job. Amazon S3 generates this ID automatically and returns it after a successful Create Job request.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited