JobDescriptor class

A container element for the job configuration and status information returned by a Describe Job request.

Constructors

JobDescriptor({bool? confirmationRequired, DateTime? creationTime, String? description, List<JobFailure>? failureReasons, String? jobArn, String? jobId, JobManifest? manifest, JobOperation? operation, int? priority, JobProgressSummary? progressSummary, JobReport? report, String? roleArn, JobStatus? status, String? statusUpdateReason, String? suspendedCause, DateTime? suspendedDate, DateTime? terminationDate})
JobDescriptor.fromXml(XmlElement elem)
factory

Properties

confirmationRequired → bool?
Indicates whether confirmation is required before Amazon S3 begins running the specified job. Confirmation is required only for jobs created through the Amazon S3 console.
final
creationTime → DateTime?
A timestamp indicating when this job was created.
final
description → String?
The description for this job, if one was provided in this job's Create Job request.
final
failureReasons → List<JobFailure>?
If the specified job failed, this field contains information describing the failure.
final
hashCode → int
The hash code for this object.
no setterinherited
jobArn → String?
The Amazon Resource Name (ARN) for this job.
final
jobId → String?
The ID for the specified job.
final
manifest → JobManifest?
The configuration information for the specified job's manifest object.
final
operation → JobOperation?
The operation that the specified job is configured to run on the objects listed in the manifest.
final
priority → int?
The priority of the specified job.
final
progressSummary → JobProgressSummary?
Describes the total number of tasks that the specified job has run, the number of tasks that succeeded, and the number of tasks that failed.
final
report → JobReport?
Contains the configuration information for the job-completion report if you requested one in the Create Job request.
final
roleArn → String?
The Amazon Resource Name (ARN) for the AWS Identity and Access Management (IAM) role assigned to run the tasks for this job.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → JobStatus?
The current status of the specified job.
final
statusUpdateReason → String?
The reason for updating the job.
final
suspendedCause → String?
The reason why the specified job was suspended. A job is only suspended if you create it through the Amazon S3 console. When you create the job, it enters the Suspended state to await confirmation before running. After you confirm the job, it automatically exits the Suspended state.
final
suspendedDate → DateTime?
The timestamp when this job was suspended, if it has been suspended.
final
terminationDate → DateTime?
A timestamp indicating when this job terminated. A job's termination date is the date and time when it succeeded, failed, or was canceled.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited