JobListDescriptor class

Contains the configuration and status information for a single job retrieved as part of a job list.

Constructors

JobListDescriptor({DateTime? creationTime, String? description, String? jobId, OperationName? operation, int? priority, JobProgressSummary? progressSummary, JobStatus? status, DateTime? terminationDate})
JobListDescriptor.fromXml(XmlElement elem)
factory

Properties

creationTime → DateTime?
A timestamp indicating when the specified job was created.
final
description → String?
The user-specified description that was included in the specified job's Create Job request.
final
hashCode → int
The hash code for this object.
no setterinherited
jobId → String?
The ID for the specified job.
final
operation → OperationName?
The operation that the specified job is configured to run on each object listed in the manifest.
final
priority → int?
The current priority for the specified job.
final
progressSummary → JobProgressSummary?
Describes the total number of tasks that the specified job has run, the number of tasks that succeeded, and the number of tasks that failed.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → JobStatus?
The specified job's current status.
final
terminationDate → DateTime?
A timestamp indicating when the specified job terminated. A job's termination date is the date and time when it succeeded, failed, or was canceled.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited