JobOperation class

The operation that you want this job to perform on each object listed in the manifest. For more information about the available operations, see Operations in the Amazon Simple Storage Service Developer Guide.

Constructors

JobOperation({LambdaInvokeOperation? lambdaInvoke, S3InitiateRestoreObjectOperation? s3InitiateRestoreObject, S3SetObjectAclOperation? s3PutObjectAcl, S3CopyObjectOperation? s3PutObjectCopy, S3SetObjectLegalHoldOperation? s3PutObjectLegalHold, S3SetObjectRetentionOperation? s3PutObjectRetention, S3SetObjectTaggingOperation? s3PutObjectTagging})
JobOperation.fromXml(XmlElement elem)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
lambdaInvoke → LambdaInvokeOperation?
Directs the specified job to invoke an AWS Lambda function on each object in the manifest.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s3InitiateRestoreObject → S3InitiateRestoreObjectOperation?
Directs the specified job to run an Initiate Glacier Restore call on each object in the manifest.
final
s3PutObjectAcl → S3SetObjectAclOperation?
Directs the specified job to run a PUT Object acl call on each object in the manifest.
final
s3PutObjectCopy → S3CopyObjectOperation?
Directs the specified job to run a PUT Copy object call on each object in the manifest.
final
s3PutObjectLegalHold → S3SetObjectLegalHoldOperation?
final
s3PutObjectRetention → S3SetObjectRetentionOperation?
final
s3PutObjectTagging → S3SetObjectTaggingOperation?
Directs the specified job to run a PUT Object tagging call on each object in the manifest.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toXml(String elemName, {List<XmlAttribute>? attributes}) → XmlElement

Operators

operator ==(Object other) → bool
The equality operator.
inherited