LifecycleConfiguration class

The container for the Outposts bucket lifecycle configuration.

Constructors

LifecycleConfiguration({List<LifecycleRule>? rules})

Properties

hashCode → int
The hash code for this object.
no setterinherited
rules → List<LifecycleRule>?
A lifecycle rule for individual objects in an Outposts bucket.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toXml(String elemName, {List<XmlAttribute>? attributes}) → XmlElement

Operators

operator ==(Object other) → bool
The equality operator.
inherited