LifecycleRuleFilter class

The container for the filter of the lifecycle rule.

Constructors

LifecycleRuleFilter({LifecycleRuleAndOperator? and, String? prefix, S3Tag? tag})
LifecycleRuleFilter.fromXml(XmlElement elem)
factory

Properties

and → LifecycleRuleAndOperator?
The container for the AND condition for the lifecycle rule.
final
hashCode → int
The hash code for this object.
no setterinherited
prefix → String?
Prefix identifying one or more objects to which the rule applies.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tag → S3Tag?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toXml(String elemName, {List<XmlAttribute>? attributes}) → XmlElement

Operators

operator ==(Object other) → bool
The equality operator.
inherited