PrefixLevelStorageMetrics class

A container for the prefix-level storage metrics for S3 Storage Lens.

Constructors

PrefixLevelStorageMetrics({bool? isEnabled, SelectionCriteria? selectionCriteria})
PrefixLevelStorageMetrics.fromXml(XmlElement elem)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isEnabled → bool?
A container for whether prefix-level storage metrics are enabled.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectionCriteria → SelectionCriteria?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toXml(String elemName, {List<XmlAttribute>? attributes}) → XmlElement

Operators

operator ==(Object other) → bool
The equality operator.
inherited