PutStorageLensConfigurationRequest class

Constructors

PutStorageLensConfigurationRequest({required String accountId, required String configId, required StorageLensConfiguration storageLensConfiguration, List<StorageLensTag>? tags})

Properties

accountId → String
The account ID of the requester.
final
configId → String
The ID of the S3 Storage Lens configuration.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storageLensConfiguration → StorageLensConfiguration
The S3 Storage Lens configuration.
final
tags → List<StorageLensTag>?
The tag set of the S3 Storage Lens configuration.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toXml(String elemName, {List<XmlAttribute>? attributes}) → XmlElement

Operators

operator ==(Object other) → bool
The equality operator.
inherited