S3AccessControlList class

Constructors

S3AccessControlList({required S3ObjectOwner owner, List<S3Grant>? grants})
S3AccessControlList.fromXml(XmlElement elem)
factory

Properties

grants → List<S3Grant>?
final
hashCode → int
The hash code for this object.
no setterinherited
owner → S3ObjectOwner
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toXml(String elemName, {List<XmlAttribute>? attributes}) → XmlElement

Operators

operator ==(Object other) → bool
The equality operator.
inherited