S3BucketDestination class

A container for the bucket where the Amazon S3 Storage Lens metrics export files are located.

Constructors

S3BucketDestination({required String accountId, required String arn, required Format format, required OutputSchemaVersion outputSchemaVersion, StorageLensDataExportEncryption? encryption, String? prefix})
S3BucketDestination.fromXml(XmlElement elem)
factory

Properties

accountId → String
The account ID of the owner of the S3 Storage Lens metrics export bucket.
final
arn → String
The Amazon Resource Name (ARN) of the bucket. This property is read-only and follows the following format: arn:aws:s3:us-east-1:example-account-id:bucket/your-destination-bucket-name
final
encryption → StorageLensDataExportEncryption?
The container for the type encryption of the metrics exports in this bucket.
final
format → Format
final
hashCode → int
The hash code for this object.
no setterinherited
outputSchemaVersion → OutputSchemaVersion
The schema version of the export file.
final
prefix → String?
The prefix of the destination bucket where the metrics export will be delivered.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toXml(String elemName, {List<XmlAttribute>? attributes}) → XmlElement

Operators

operator ==(Object other) → bool
The equality operator.
inherited