S3Control class

AWS S3 Control provides access to Amazon S3 control plane operations.

Constructors

S3Control({required String region, AwsClientCredentials? credentials, AwsClientCredentialsProvider? credentialsProvider, Client? client, String? endpointUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the internal HTTP client if none was provided at creation. If a client was passed as a constructor argument, this becomes a noop.
createAccessPoint({required String accountId, required String bucket, required String name, PublicAccessBlockConfiguration? publicAccessBlockConfiguration, VpcConfiguration? vpcConfiguration}) Future<CreateAccessPointResult>
Creates an access point and associates it with the specified bucket. For more information, see Managing Data Access with Amazon S3 Access Points in the Amazon Simple Storage Service Developer Guide.
createBucket({required String bucket, BucketCannedACL? acl, CreateBucketConfiguration? createBucketConfiguration, String? grantFullControl, String? grantRead, String? grantReadACP, String? grantWrite, String? grantWriteACP, bool? objectLockEnabledForBucket, String? outpostId}) Future<CreateBucketResult>
This API operation creates an Amazon S3 on Outposts bucket. To create an S3 bucket, see Create Bucket in the Amazon Simple Storage Service API.
createJob({required String accountId, required JobManifest manifest, required JobOperation operation, required int priority, required JobReport report, required String roleArn, String? clientRequestToken, bool? confirmationRequired, String? description, List<S3Tag>? tags}) Future<CreateJobResult>
S3 Batch Operations performs large-scale Batch Operations on Amazon S3 objects. Batch Operations can run a single operation or action on lists of Amazon S3 objects that you specify. For more information, see S3 Batch Operations in the Amazon Simple Storage Service Developer Guide.
deleteAccessPoint({required String accountId, required String name}) Future<void>
Deletes the specified access point.
deleteAccessPointPolicy({required String accountId, required String name}) Future<void>
Deletes the access point policy for the specified access point.
deleteBucket({required String accountId, required String bucket}) Future<void>
This API operation deletes an Amazon S3 on Outposts bucket. To delete an S3 bucket, see DeleteBucket in the Amazon Simple Storage Service API.
deleteBucketLifecycleConfiguration({required String accountId, required String bucket}) Future<void>
This API action deletes an Amazon S3 on Outposts bucket's lifecycle configuration. To delete an S3 bucket's lifecycle configuration, see DeleteBucketLifecycle in the Amazon Simple Storage Service API.
deleteBucketPolicy({required String accountId, required String bucket}) Future<void>
This API operation deletes an Amazon S3 on Outposts bucket policy. To delete an S3 bucket policy, see DeleteBucketPolicy in the Amazon Simple Storage Service API.
deleteBucketTagging({required String accountId, required String bucket}) Future<void>
This operation deletes an Amazon S3 on Outposts bucket's tags. To delete an S3 bucket tags, see DeleteBucketTagging in the Amazon Simple Storage Service API.
deleteJobTagging({required String accountId, required String jobId}) Future<void>
Removes the entire tag set from the specified S3 Batch Operations job. To use this operation, you must have permission to perform the s3:DeleteJobTagging action. For more information, see Controlling access and labeling jobs using tags in the Amazon Simple Storage Service Developer Guide.
deletePublicAccessBlock({required String accountId}) Future<void>
Removes the PublicAccessBlock configuration for an AWS account. For more information, see Using Amazon S3 block public access.
deleteStorageLensConfiguration({required String accountId, required String configId}) Future<void>
Deletes the Amazon S3 Storage Lens configuration. For more information about S3 Storage Lens, see Working with Amazon S3 Storage Lens in the Amazon Simple Storage Service Developer Guide.
deleteStorageLensConfigurationTagging({required String accountId, required String configId}) Future<void>
Deletes the Amazon S3 Storage Lens configuration tags. For more information about S3 Storage Lens, see Working with Amazon S3 Storage Lens in the Amazon Simple Storage Service Developer Guide.
describeJob({required String accountId, required String jobId}) Future<DescribeJobResult>
Retrieves the configuration parameters and status for a Batch Operations job. For more information, see S3 Batch Operations in the Amazon Simple Storage Service Developer Guide.
getAccessPoint({required String accountId, required String name}) Future<GetAccessPointResult>
Returns configuration information about the specified access point.
getAccessPointPolicy({required String accountId, required String name}) Future<GetAccessPointPolicyResult>
Returns the access point policy associated with the specified access point.
getAccessPointPolicyStatus({required String accountId, required String name}) Future<GetAccessPointPolicyStatusResult>
Indicates whether the specified access point currently has a policy that allows public access. For more information about public access through access points, see Managing Data Access with Amazon S3 Access Points in the Amazon Simple Storage Service Developer Guide.
getBucket({required String accountId, required String bucket}) Future<GetBucketResult>
Gets an Amazon S3 on Outposts bucket. For more information, see Using Amazon S3 on Outposts in the Amazon Simple Storage Service Developer Guide.
getBucketLifecycleConfiguration({required String accountId, required String bucket}) Future<GetBucketLifecycleConfigurationResult>
This operation gets an Amazon S3 on Outposts bucket's lifecycle configuration. To get an S3 bucket's lifecycle configuration, see GetBucketLifecycleConfiguration in the Amazon Simple Storage Service API.
getBucketPolicy({required String accountId, required String bucket}) Future<GetBucketPolicyResult>
This action gets a bucket policy for an Amazon S3 on Outposts bucket. To get a policy for an S3 bucket, see GetBucketPolicy in the Amazon Simple Storage Service API.
getBucketTagging({required String accountId, required String bucket}) Future<GetBucketTaggingResult>
This operation gets an Amazon S3 on Outposts bucket's tags. To get an S3 bucket tags, see GetBucketTagging in the Amazon Simple Storage Service API.
getJobTagging({required String accountId, required String jobId}) Future<GetJobTaggingResult>
Returns the tags on an S3 Batch Operations job. To use this operation, you must have permission to perform the s3:GetJobTagging action. For more information, see Controlling access and labeling jobs using tags in the Amazon Simple Storage Service Developer Guide.
getPublicAccessBlock({required String accountId}) Future<GetPublicAccessBlockOutput>
Retrieves the PublicAccessBlock configuration for an AWS account. For more information, see Using Amazon S3 block public access.
getStorageLensConfiguration({required String accountId, required String configId}) Future<GetStorageLensConfigurationResult>
Gets the Amazon S3 Storage Lens configuration. For more information, see Working with Amazon S3 Storage Lens in the Amazon Simple Storage Service Developer Guide.
getStorageLensConfigurationTagging({required String accountId, required String configId}) Future<GetStorageLensConfigurationTaggingResult>
Gets the tags of Amazon S3 Storage Lens configuration. For more information about S3 Storage Lens, see Working with Amazon S3 Storage Lens in the Amazon Simple Storage Service Developer Guide.
listAccessPoints({required String accountId, String? bucket, int? maxResults, String? nextToken}) Future<ListAccessPointsResult>
Returns a list of the access points currently associated with the specified bucket. You can retrieve up to 1000 access points per call. If the specified bucket has more than 1,000 access points (or the number specified in maxResults, whichever is less), the response will include a continuation token that you can use to list the additional access points.
listJobs({required String accountId, List<JobStatus>? jobStatuses, int? maxResults, String? nextToken}) Future<ListJobsResult>
Lists current S3 Batch Operations jobs and jobs that have ended within the last 30 days for the AWS account making the request. For more information, see S3 Batch Operations in the Amazon Simple Storage Service Developer Guide.
listRegionalBuckets({required String accountId, int? maxResults, String? nextToken, String? outpostId}) Future<ListRegionalBucketsResult>
Returns a list of all Outposts buckets in an Outpost that are owned by the authenticated sender of the request. For more information, see Using Amazon S3 on Outposts in the Amazon Simple Storage Service Developer Guide.
listStorageLensConfigurations({required String accountId, String? nextToken}) Future<ListStorageLensConfigurationsResult>
Gets a list of Amazon S3 Storage Lens configurations. For more information about S3 Storage Lens, see Working with Amazon S3 Storage Lens in the Amazon Simple Storage Service Developer Guide.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putAccessPointPolicy({required String accountId, required String name, required String policy}) Future<void>
Associates an access policy with the specified access point. Each access point can have only one policy, so a request made to this API replaces any existing policy associated with the specified access point.
putBucketLifecycleConfiguration({required String accountId, required String bucket, LifecycleConfiguration? lifecycleConfiguration}) Future<void>
This action puts a lifecycle configuration to an Amazon S3 on Outposts bucket. To put a lifecycle configuration to an S3 bucket, see PutBucketLifecycleConfiguration in the Amazon Simple Storage Service API.
putBucketPolicy({required String accountId, required String bucket, required String policy, bool? confirmRemoveSelfBucketAccess}) Future<void>
This action puts a bucket policy to an Amazon S3 on Outposts bucket. To put a policy on an S3 bucket, see PutBucketPolicy in the Amazon Simple Storage Service API.
putBucketTagging({required String accountId, required String bucket, required Tagging tagging}) Future<void>
This action puts tags on an Amazon S3 on Outposts bucket. To put tags on an S3 bucket, see PutBucketTagging in the Amazon Simple Storage Service API.
putJobTagging({required String accountId, required String jobId, required List<S3Tag> tags}) Future<void>
Sets the supplied tag-set on an S3 Batch Operations job.
putPublicAccessBlock({required String accountId, required PublicAccessBlockConfiguration publicAccessBlockConfiguration}) Future<void>
Creates or modifies the PublicAccessBlock configuration for an AWS account. For more information, see Using Amazon S3 block public access.
putStorageLensConfiguration({required String accountId, required String configId, required StorageLensConfiguration storageLensConfiguration, List<StorageLensTag>? tags}) Future<void>
Puts an Amazon S3 Storage Lens configuration. For more information about S3 Storage Lens, see Working with Amazon S3 Storage Lens in the Amazon Simple Storage Service Developer Guide.
putStorageLensConfigurationTagging({required String accountId, required String configId, required List<StorageLensTag> tags}) Future<void>
Put or replace tags on an existing Amazon S3 Storage Lens configuration. For more information about S3 Storage Lens, see Working with Amazon S3 Storage Lens in the Amazon Simple Storage Service Developer Guide.
toString() String
A string representation of this object.
inherited
updateJobPriority({required String accountId, required String jobId, required int priority}) Future<UpdateJobPriorityResult>
Updates an existing S3 Batch Operations job's priority. For more information, see S3 Batch Operations in the Amazon Simple Storage Service Developer Guide.
updateJobStatus({required String accountId, required String jobId, required RequestedJobStatus requestedJobStatus, String? statusUpdateReason}) Future<UpdateJobStatusResult>
Updates the status for the specified job. Use this operation to confirm that you want to run a job or to cancel an existing job. For more information, see S3 Batch Operations in the Amazon Simple Storage Service Developer Guide.

Operators

operator ==(Object other) bool
The equality operator.
inherited