S3CopyObjectOperation class

Contains the configuration parameters for a PUT Copy object operation. S3 Batch Operations passes each value through to the underlying PUT Copy object API. For more information about the parameters for this operation, see PUT Object - Copy.

Constructors

S3CopyObjectOperation({List<S3Grant>? accessControlGrants, S3CannedAccessControlList? cannedAccessControlList, S3MetadataDirective? metadataDirective, DateTime? modifiedSinceConstraint, S3ObjectMetadata? newObjectMetadata, List<S3Tag>? newObjectTagging, S3ObjectLockLegalHoldStatus? objectLockLegalHoldStatus, S3ObjectLockMode? objectLockMode, DateTime? objectLockRetainUntilDate, String? redirectLocation, bool? requesterPays, String? sSEAwsKmsKeyId, S3StorageClass? storageClass, String? targetKeyPrefix, String? targetResource, DateTime? unModifiedSinceConstraint})
S3CopyObjectOperation.fromXml(XmlElement elem)
factory

Properties

accessControlGrants → List<S3Grant>?
final
cannedAccessControlList → S3CannedAccessControlList?
final
hashCode → int
The hash code for this object.
no setterinherited
metadataDirective → S3MetadataDirective?
final
modifiedSinceConstraint → DateTime?
final
newObjectMetadata → S3ObjectMetadata?
final
newObjectTagging → List<S3Tag>?
final
objectLockLegalHoldStatus → S3ObjectLockLegalHoldStatus?
The legal hold status to be applied to all objects in the Batch Operations job.
final
objectLockMode → S3ObjectLockMode?
The retention mode to be applied to all objects in the Batch Operations job.
final
objectLockRetainUntilDate → DateTime?
The date when the applied object retention configuration expires on all objects in the Batch Operations job.
final
redirectLocation → String?
Specifies an optional metadata property for website redirects, x-amz-website-redirect-location. Allows webpage redirects if the object is accessed through a website endpoint.
final
requesterPays → bool?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sSEAwsKmsKeyId → String?
final
storageClass → S3StorageClass?
final
targetKeyPrefix → String?
Specifies the folder prefix into which you would like the objects to be copied. For example, to copy objects into a folder named "Folder1" in the destination bucket, set the TargetKeyPrefix to "Folder1/".
final
targetResource → String?
Specifies the destination bucket ARN for the batch copy operation. For example, to copy objects to a bucket named "destinationBucket", set the TargetResource to "arn:aws:s3:::destinationBucket".
final
unModifiedSinceConstraint → DateTime?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toXml(String elemName, {List<XmlAttribute>? attributes}) → XmlElement

Operators

operator ==(Object other) → bool
The equality operator.
inherited