S3ObjectMetadata class

Constructors

S3ObjectMetadata({String? cacheControl, String? contentDisposition, String? contentEncoding, String? contentLanguage, int? contentLength, String? contentMD5, String? contentType, DateTime? httpExpiresDate, bool? requesterCharged, S3SSEAlgorithm? sSEAlgorithm, Map<String, String>? userMetadata})
S3ObjectMetadata.fromXml(XmlElement elem)
factory

Properties

cacheControl → String?
final
contentDisposition → String?
final
contentEncoding → String?
final
contentLanguage → String?
final
contentLength → int?
final
contentMD5 → String?
final
contentType → String?
final
hashCode → int
The hash code for this object.
no setterinherited
httpExpiresDate → DateTime?
final
requesterCharged → bool?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sSEAlgorithm → S3SSEAlgorithm?
final
userMetadata → Map<String, String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toXml(String elemName, {List<XmlAttribute>? attributes}) → XmlElement

Operators

operator ==(Object other) → bool
The equality operator.
inherited