StorageLensConfiguration class

A container for the Amazon S3 Storage Lens configuration.

Constructors

StorageLensConfiguration({required AccountLevel accountLevel, required String id, required bool isEnabled, StorageLensAwsOrg? awsOrg, StorageLensDataExport? dataExport, Exclude? exclude, Include? include, String? storageLensArn})
StorageLensConfiguration.fromXml(XmlElement elem)
factory

Properties

accountLevel → AccountLevel
A container for all the account-level configurations of your S3 Storage Lens configuration.
final
awsOrg → StorageLensAwsOrg?
A container for the AWS organization for this S3 Storage Lens configuration.
final
dataExport → StorageLensDataExport?
A container to specify the properties of your S3 Storage Lens metrics export including, the destination, schema and format.
final
exclude → Exclude?
A container for what is excluded in this configuration. This container can only be valid if there is no Include container submitted, and it's not empty.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
A container for the Amazon S3 Storage Lens configuration ID.
final
include → Include?
A container for what is included in this configuration. This container can only be valid if there is no Exclude container submitted, and it's not empty.
final
isEnabled → bool
A container for whether the S3 Storage Lens configuration is enabled.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storageLensArn → String?
The Amazon Resource Name (ARN) of the S3 Storage Lens configuration. This property is read-only and follows the following format: arn:aws:s3:us-east-1:example-account-id:storage-lens/your-dashboard-name
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toXml(String elemName, {List<XmlAttribute>? attributes}) → XmlElement

Operators

operator ==(Object other) → bool
The equality operator.
inherited