Transition class

Specifies when an object transitions to a specified storage class. For more information about Amazon S3 Lifecycle configuration rules, see Transitioning objects using Amazon S3 Lifecycle in the Amazon Simple Storage Service Developer Guide.

Constructors

Transition({DateTime? date, int? days, TransitionStorageClass? storageClass})
Transition.fromXml(XmlElement elem)
factory

Properties

date → DateTime?
Indicates when objects are transitioned to the specified storage class. The date value must be in ISO 8601 format. The time is always midnight UTC.
final
days → int?
Indicates the number of days after creation when objects are transitioned to the specified storage class. The value must be a positive integer.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storageClass → TransitionStorageClass?
The storage class to which you want the object to transition.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toXml(String elemName, {List<XmlAttribute>? attributes}) → XmlElement

Operators

operator ==(Object other) → bool
The equality operator.
inherited