UpdateJobStatusResult class

Constructors

UpdateJobStatusResult({String? jobId, JobStatus? status, String? statusUpdateReason})
UpdateJobStatusResult.fromXml(XmlElement elem)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
jobId → String?
The ID for the job whose status was updated.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → JobStatus?
The current status for the specified job.
final
statusUpdateReason → String?
The reason that the specified job's status was updated.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited