VpcConfiguration class

The virtual private cloud (VPC) configuration for an access point.

Constructors

VpcConfiguration({required String vpcId})
VpcConfiguration.fromXml(XmlElement elem)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vpcId → String
If this field is specified, this access point will only allow connections from the specified VPC ID.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toXml(String elemName, {List<XmlAttribute>? attributes}) → XmlElement

Operators

operator ==(Object other) → bool
The equality operator.
inherited